@@ -98,6 +98,12 @@ AndroidMediaLibrary::banFolder(const std::string& path)
     p_ml->banFolder(path);
 }
 
+void
+AndroidMediaLibrary::unbanFolder(const std::string& path)
+{
+    p_ml->unbanFolder(path);
+}
+
 void
 AndroidMediaLibrary::discover(const std::string& libraryPath)
 {
