@@ -99,7 +99,12 @@ public class Medialibrary {
 
     public void banFolder(@NonNull String path) {
         if (mIsInitiated && new File(path).exists())
-            nativeBanFolder(Tools.encodeVLCMrl(path));
+            nativeBanFolder(Tools.encodeVLCMrl(Uri.encode(path, "/")));
+    }
+
+    public void unbanFolder(@NonNull String path) {
+        if (mIsInitiated && new File(path).exists())
+            nativeUnbanFolder(Tools.encodeVLCMrl(Uri.encode(path, "/")));
     }
 
     public String[] getDevices() {
@@ -233,7 +238,7 @@ public class Medialibrary {
 
     public void reload(String entryPoint) {
         if (mIsInitiated && !TextUtils.isEmpty(entryPoint))
-            nativeReload(entryPoint);
+            nativeReload(Tools.encodeVLCMrl(entryPoint));
     }
 
     public void forceParserRetry() {
@@ -569,6 +574,7 @@ public class Medialibrary {
                 "/audio/alarms/",
                 "/audio/ringtones/",
                 "/audio/notifications/",
+                "/WhatsApp/Media/WhatsApp Animated Gifs/",
         };
     }
 
@@ -594,6 +600,7 @@ public class Medialibrary {
     private native void nativeStart();
     private native void nativeRelease();
     private native void nativeBanFolder(String path);
+    private native void nativeUnbanFolder(String path);
     private native boolean nativeAddDevice(String uuid, String path, boolean removable);
     private native String[] nativeDevices();
     private native void nativeDiscover(String path);
