@@ -120,8 +120,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     @Override
     protected void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        if (mSettings.getBoolean(PreferencesActivity.AUTO_RESCAN, true) && Permissions.canReadStorage())
-            mMediaLibrary.reload();
 
         if (!VLCInstance.testCompatibleCPU(this)) {
             finish();
@@ -386,23 +384,15 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     };
 
     private class AsyncUpdate extends AsyncTask<Void, Void, Void> {
-        boolean showHistory;
-        MediaWrapper[] history, videoList;
+        private boolean showHistory;
+        private MediaWrapper[] history, videoList;
 
         AsyncUpdate() {}
 
         @Override
         protected void onPreExecute() {
             showHistory = mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true);
-            if (mRowsAdapter != null)
-                mRowsAdapter.clear();
-            else
-                mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
             mHandler.sendEmptyMessageDelayed(SHOW_LOADING, 300);
-            mHistoryIndex.clear();
-
-            //Video Section
-            mVideoIndex.clear();
         }
 
         @Override
@@ -425,6 +415,13 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mHandler.sendEmptyMessage(HIDE_LOADING);
             if (!isVisible())
                 return;
+            if (mRowsAdapter != null)
+                mRowsAdapter.clear();
+            else
+                mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
+            mHistoryIndex.clear();
+            //Video Section
+            mVideoIndex.clear();
             mVideoAdapter = new ArrayObjectAdapter(
                     new CardPresenter(mContext));
             final HeaderItem videoHeader = new HeaderItem(HEADER_VIDEO, getString(R.string.video));
@@ -556,10 +553,12 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     public void updateNowPlayingCard () {
         if (mService == null)
             return;
-        if ((!mService.hasMedia() || mService.canSwitchToVideo()) && mNowPlayingCard != null) {
+        final boolean hasmedia = mService.hasMedia();
+        final boolean canSwitch = mService.canSwitchToVideo();
+        if ((!hasmedia || canSwitch) && mNowPlayingCard != null) {
             mCategoriesAdapter.removeItems(0, 1);
             mNowPlayingCard = null;
-        } else  if (mService.hasMedia()){
+        } else if (hasmedia && !canSwitch){
             final MediaWrapper mw = mService.getCurrentMediaWrapper();
             final String display = MediaUtils.getMediaTitle(mw) + " - " + MediaUtils.getMediaReferenceArtist(MainTvActivity.this, mw);
             VLCApplication.runBackground(new Runnable() {
