@@ -74,7 +74,6 @@ import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.regex.Pattern;
 
 public class VideoGridFragment extends SortableFragment<VideoListAdapter> implements MediaUpdatedCb, SwipeRefreshLayout.OnRefreshListener, MediaAddedCb, Filterable, IEventsHandler {
 
@@ -96,7 +95,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     @Override
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        mAdapter = new VideoListAdapter(this);
+        mAdapter = new VideoListAdapter(this, mGroup != null);
 
         if (savedInstanceState != null)
             setGroup(savedInstanceState.getString(KEY_GROUP));
@@ -293,9 +292,10 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     }
 
     private void removeVideo(final MediaWrapper media) {
-        mAdapter.remove(media);
-        if (getView() != null)
-            UiTools.snackerWithCancel(getView(), getString(R.string.file_deleted), new Runnable() {
+        final int position = mAdapter.remove(media);
+        final View view = getView();
+        if (position != -1 && view != null)
+            UiTools.snackerWithCancel(view, getString(R.string.file_deleted), new Runnable() {
                 @Override
                 public void run() {
                     deleteMedia(media, false);
@@ -303,7 +303,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
             }, new Runnable() {
                 @Override
                 public void run() {
-                    mAdapter.add(media);
+                    mAdapter.add(media, position);
                 }
             });
     }
@@ -366,11 +366,8 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
                 if (mGroup != null) {
                     for (MediaWrapper item : itemList) {
                         String title = item.getTitle().substring(item.getTitle().toLowerCase().startsWith("the") ? 4 : 0);
-                        if (title.toLowerCase().startsWith(mGroup.toLowerCase())) {
-                            //Display title without the group name
-                            item.setDisplayTitle(title.replaceFirst(Pattern.quote(mGroup), "\u2026"));
+                        if (mGroup == null || title.toLowerCase().startsWith(mGroup.toLowerCase()))
                             displayList.add(item);
-                        }
                     }
                 } else {
                     for (MediaGroup item : MediaGroup.group(itemList))
